pub fn delete_token(redmine_url: &str) -> bool
Removes the stored Redmine token for a specific Redmine instance from the OS keyring.
Returns true if the entry was deleted successfully, false otherwise.
true
false